@@ -493,7 +493,7 @@ class AbstractFileDataType(DataType):
         absFileName = os.path.join( src.getDir() , srcFileName )
         all_converters = _cfg.dataconverter( self.__class__.__name__[:-8] )
         in_format = detectedMobyleType.getDataFormat()
-        
+       
         if not all_converters:
             fileName = safeFileName( absFileName )
             if detectedMobyleType :
@@ -516,19 +516,18 @@ class AbstractFileDataType(DataType):
                 return result
                 
             def fixed_converter( in_format ,  converter ):
-                allowed_conversions = detector_used.convertedFormat()
+                allowed_conversions = converter.convertedFormat()
                 for out_format , force in acceptedMobyleType.getAcceptedFormats():
                     if ( in_format , out_format ) in allowed_conversions:
                         try:
                             outFileName = converter.convert( absFileName , out_format , inputFormat = in_format )
                             outFileName = os.path.basename( outFileName )
                         except UnSupportedFormatError, err:
-                            raise UserValueError( msg = "a problem occurred during the data conversion : "+str( err ) ) 
-                        converted_mt = MobyleType( self  , dataFormat = out_format , format_program = detector_used.program_name )
+                            raise UnSupportedFormatError( msg = "a problem occurred during the data conversion : "+str( err ) ) 
+                        converted_mt = MobyleType( self  , dataFormat = out_format , format_program = converter.program_name )
                         return ( outFileName , converted_mt )
                 #it's not a suitable converter
                 return None
-            
             if detectedMobyleType.format_program is None:
                 result = unknow_converter( in_format , all_converters )
             else:
@@ -541,7 +540,6 @@ class AbstractFileDataType(DataType):
                 result  = fixed_converter( in_format , detector_used )
                 if result is None:# the detector_used is not suitable for the conversion
                     result= unknow_converter( in_format , [ c for c in all_converters if c != detector_used ] )
-                    
             if result is None:
                 raise UnSupportedFormatError( "unable to convert %s in %s sequence format" %( in_format , 
                                                                                               [ f[0] for f in acceptedMobyleType.getAcceptedFormats() ] 
@@ -579,10 +577,7 @@ class AbstractFileDataType(DataType):
                         if  not mask or mask != filename :
                             msg = "The Parameter:%s, have an unsecure filenames value: %s " %( param.getName() ,
                                                                                                 filename )
-                            c_log.error( admMsg = "MobyleJob._validateParameters : " + msg ,
-                                            logMsg = None ,
-                                            userMsg = "Mobyle Internal Server Error"
-                                            )
+                            c_log.error("Mobyle Internal Server Error")
                             if debug == 0:
                                 c_log.critical( "%s : %s : %s" %( self._service.getName(),
                                                                        self._job.getKey() ,
