@@ -221,6 +221,9 @@ class DRMAA(ExecutionSystem):
                     if jobInfos[ 1 ]:#hasExited
                         if jobInfos[ 6 ] == 0:#exitStatus
                             status = Status( code = 4 ) #finished
+                        elif pipe.returncode < 0 or pipe.returncode > 128:
+                            #all the signals that we don't know where they come from
+                            status = Status( code = 5 , message = "Your job execution failed ( %s )" %pipe.returncode )    
                         else:
                             status = Status( code = 4 , message = "Your job finished with an unusual status code ( %d ), check your results carefully." % jobInfos[ 6 ] )
                     else:
