@@ -51,9 +51,9 @@ class SYS(ExecutionSystem):
             # and execute the command prior to return.
             # in these conditions we could kill the process leader and the signal is propagate to
             # all processes belonging to this session. 
-
+            command_path =  os.path.join( dirPath , ".command" )
             setsidPath = '%s/Tools/setsid' %self._cfg.mobylehome()
-            command = [ setsidPath , setsidPath , '/bin/sh' , '-c' , commandLine ]
+            command = [ setsidPath , setsidPath , '/bin/sh' , command_path ]
             # _log.debug("SYS env : %s\n" % str(self.xmlEnv) )
 
             pipe = Popen( command ,
