@@ -34,6 +34,10 @@ from Mobyle.Status import Status
 from Mobyle.StatusManager import StatusManager
 from Mobyle.DataProvider import DataProvider
 from JobState import ProgramJobState, WorkflowJobState
+#BEGIN #819
+from Mobyle.Service import MobyleType
+from Mobyle.Classes.Core import AbstractTextDataType
+#END #819
 
 from Mobyle.ConfigManager import Config
 _cfg = Config()
@@ -55,6 +59,20 @@ class JobFacade(object):
             self.jobId = jobId
         self.workflowId = workflowId
 
+    def _getFormValuesToAddToSession(self,session, param):
+        if param['srcFileName'] and not(param['value']):
+            param['userName'] = session.getData(param['srcFileName'])['userName']
+        if param['value'] and not(param['srcFileName']):
+            try:
+                param['srcFileName'] = \
+                session.addData( param['userName'], \
+                                  param['parameter'].getType(), \
+                                  content = param['value'], \
+                                  inputModes = [param['inputMode']])
+            except NoSpaceLeftError, err:
+                raise UserValueError(param.get('parameter'), msg=err.message)
+        return param['srcFileName']
+    
     def addJobToSession(self, session, jobInfo):
         """
         links the job to a session by:
@@ -67,24 +85,48 @@ class JobFacade(object):
         @type: dictionary
         """
         dataUsed = []
-        for name, param in [(name, param) for name, param in self.params.items() \
-                      if (param.has_key('parameter') \
-                      and param['parameter'].isInfile())]:
-                if param['srcFileName'] and not(param['value']):
-                    param['userName'] = session.getData(param['srcFileName'])['userName']
-                    dataUsed.append(param['srcFileName'])
-                if param['value'] and not(param['srcFileName']):
-                    try:
-                        param['srcFileName'] = \
-                        session.addData( param['userName'], \
-                                          param['parameter'].getType(), \
-                                          content = param['value'], \
-                                          inputModes = [param['inputMode']])
-                    except NoSpaceLeftError, err:
-                        raise UserValueError(param, msg=err.message)
-                        dataUsed.append(param['srcFileName'])
-        session.addJob( jobInfo['id'],dataUsed=dataUsed)
+        for paramName in self.service.getUserInputParameterByArgpos():
+            param = self.service.getParameter(paramName)
+            if param.isInfile():
+                if param.getDataType().isMultiple():
+                    inputNames = set([inputName.partition('.')[0] for inputName in self.request.keys() if inputName.startswith(paramName+'[')])
+                    valueToSet = [self._getFormValuesToAddToSession(session,self.params[inputName]) for inputName in inputNames if self.params.has_key(inputName)]
+                    dataUsed.extend(valueToSet)
+                elif self.params.has_key(paramName):
+                    valueToSet = self._getFormValuesToAddToSession(session,self.params[paramName])
+                    dataUsed.append(valueToSet)
+        userName = self.servicePID  + ' - ' + jobInfo['date']
+        session.addJob( jobInfo['id'],userName=userName,dataUsed=dataUsed)
+        jobInfo['userName'] = userName
+        return jobInfo
 
+    def _processFormParameterValue(self, param,inputName, index=0):
+        value, userName, src, srcFileName, inputMode = None, None, None, None, None
+        if param.isInfile():
+            inputMode = self.request.get(inputName+'.mode',"upload")
+            if self.request.has_key(inputName+".ref"):
+                srcFileName = self.request.get(inputName+".ref")
+                src = self.session
+                userName = self.request.get(inputName+".name")
+            elif self.request.has_key(inputName+".src"):
+                srcFileName = self.request.get(inputName+".srcFileName")
+                src = self.request.get(inputName+".src")
+                userName = self.request.get(inputName+".name")
+            else:
+                value = self.request.get(inputName)
+                userName = inputName + ".data"
+        else:
+            value = self.request.get(inputName, None) 
+        if (value is not None and value!="") or srcFileName: # if the value is not null (or blank from BMID)...
+            self.params[inputName] = {'value': value, 
+                                      'userName': userName , 
+                                      'srcFileName': srcFileName, 
+                                      'src': src, 
+                                      'inputMode':  inputMode, 
+                                      'parameter': param,
+                                      'index':index
+                                      }
+        
     def _processForm(self):
         """
         process the cgi form:
@@ -94,33 +136,15 @@ class JobFacade(object):
         """
         for paramName in self.service.getUserInputParameterByArgpos():
             param = self.service.getParameter(paramName)
-            inputName = paramName 
-            value, userName, src, srcFileName, inputMode = None, None, None, None, None
-            if param.isInfile():
-                inputMode = self.request.get(inputName+'.mode',"upload")
-                if self.request.has_key(inputName+".ref"):
-                    srcFileName = self.request.get(inputName+".ref")
-                    src = self.session
-                    userName = self.request.get(inputName+".name")
-                elif self.request.has_key(inputName+".src"):
-                    srcFileName = self.request.get(inputName+".srcFileName")
-                    src = self.request.get(inputName+".src")
-                    userName = self.request.get(inputName+".name")
-                else:
-                    #value = self.request.get(inputName+"_data")
-                    value = self.request.get(inputName)
-                    userName = paramName + ".data"
+            if param.getDataType().isMultiple():
+                inputNames = sorted(set([inputName.partition('.')[0] for inputName in self.request.keys() if inputName.startswith(paramName+'[')]))
+                idx=0
+                for inputName in inputNames:
+                    self._processFormParameterValue(param,inputName,index=idx)
+                    idx = idx + 1
             else:
-                value = self.request.get(inputName, None) 
-            if value is not None or srcFileName: # if the value is not null...
-                self.params[paramName] = {'value': value, 
-                                          'userName': userName , 
-                                          'srcFileName': srcFileName, 
-                                          'src': src, 
-                                          'inputMode':  inputMode, 
-                                          'parameter': param
-                                          }
-
+                self._processFormParameterValue(param,paramName)
+            
     def parseService(self):
         """
         initializes the self.service and self.servicePID properties corresponding to the service url
@@ -159,6 +183,8 @@ class JobFacade(object):
         if not(self.email) and session:
             self.email = session.getEmail()
         self.parseService()
+        if hasattr(self.service,'pid'):
+            self.servicePID = self.service.pid
         if (not(simulate) and not( self.email ) and not( _cfg.opt_email( self.servicePID ) ) ):
             # test if email is needed unless it is only a simulation
             return {"emailNeeded":"true"}
@@ -433,28 +459,26 @@ class LocalJobFacade(JobFacade):
                                         #debug = (None,1)[simulate])
             else:
                 raise NotImplementedError("No Job can be instanciated for a %s service" % str(self.service.__class__))
-            for name, param in self.params.items():
+            for paramName in self.service.getUserInputParameterByArgpos():
+                param = self.service.getParameter(paramName)
                 try:
-                    if param['parameter'].isInfile():
-                        if param['src']:
-                            param['src'] = DataProvider.get(param['src'])
-                            self.job.setValue(name, (param['userName'], None, param['src'], param['srcFileName']))      
+                    if param.getDataType().isMultiple():
+                        inputNames = set([inputName.partition('.')[0] for inputName in self.request.keys() if inputName.startswith(paramName+'[')])
+                        valueToSet = [self._getFormValueToSet(self.params[inputName]) for inputName in inputNames if self.params.has_key(inputName)]
+                        j_log.error(valueToSet)
+                    else:
+                        if self.params.has_key(paramName):
+                            valueToSet = self._getFormValueToSet(self.params[paramName])
                         else:
-                            self.job.setValue(name, (param['userName'], param['value'], None, None))      
-                    else:
-                        if param['parameter'].getDataType().getName() == 'MultipleChoice': 
-                            from types import StringTypes
-                            if isinstance(  param['value'] , StringTypes ):
-                                param['value'] = [ param['value'] ]
-                        self.job.setValue(name, param['value'])
+                            continue
+                    self.job.setValue(paramName, valueToSet)
                 except MobyleError , err:
-                    if param['parameter'].promptHas_lang( "en"):
-                        userMsg = "Error while setting value for parameter: %s " %param['parameter'].getPrompt( lang="en")
+                    if param.promptHas_lang( "en"):
+                        userMsg = "Error while setting value for parameter: %s " % param.getPrompt( lang="en")
                     else:
-                        userMsg = "Error while setting value for parameter: %s " %name
+                        userMsg = "Error while setting value for parameter: %s " % param.getName()
                     sm = StatusManager ()
                     sm.setStatus( self.job.getDir() , Status( code = 5 , message = userMsg ) )
-                    j_log.error(userMsg,exc_info=True)
                     raise err
             # run Job         
             self.job.run()
@@ -493,7 +517,17 @@ class LocalJobFacade(JobFacade):
                 msg["errorparam"] = e.param.getName()
             return msg
   
-  
+    def _getFormValueToSet(self,param):
+        if param['parameter'].isInfile():
+            if param['src']:
+                param['src'] = DataProvider.get(param['src'])
+                return (param['userName'], None, param['src'], param['srcFileName'],param['index'])
+            else:
+                return (param['userName'], param['value'], None, None,param['index'])
+        else:
+            return param['value']
+
+        
     def getStatus(self):
         """
         gets the job status on the local server
@@ -538,6 +572,10 @@ class LocalJobFacade(JobFacade):
             # we can do something about it if necessary, otherwise accessing them
             # is too much work...
             #execution_details['env']=self.job._job.runner._xmlEnv
+            st = utils_getStatus( self.jobId )
+            execution_details['status']={'code':str(st),'message':st.message}
+            if st.isOnError():
+                execution_details['errormsg']=st.message
         return execution_details
 
         
@@ -545,4 +583,4 @@ class LocalJobFacade(JobFacade):
         """
         
         """
-        utils_killJob( self.jobId )
\ No newline at end of file
+        utils_killJob( self.jobId )
