@@ -322,7 +322,6 @@ class _abstractState( object ):
         """
         self._parse( )
         fileNodes = self.root.xpath( "./data/output[ parameter/name = '" + parameterName + "' ]/file" )
-        
         files =[]
         for fileNode in fileNodes:
             filename =  fileNode.text 
@@ -335,8 +334,29 @@ class _abstractState( object ):
             return files
         else:
             return None
-
-
+    
+    def getInput(self, parameterName):
+        self._parse( )
+        fileNodes = self.root.xpath( "./data/input[ parameter/name = '" + parameterName + "' ]/file" )
+        files =[] 
+        
+        def xml_to_tuple( node ):
+            fileName= str( node.text)
+            size = long( node.get( "size" ) )
+            fmt = node.get( "fmt" , None ) 
+            if fmt :
+                fmt = str( fmt )
+            return ( fileName , size , fmt )
+        
+        for fileNode in fileNodes:
+            rawNode = fileNode.find( 'raw')
+            files.append( xml_to_tuple( rawNode ) )
+            convNode = fileNode.find( 'formattedFile' )
+            if convNode is not None :
+                files.append( xml_to_tuple( convNode ) )
+        return files
+           
+           
     def getInputFiles( self ):
         """
         @return: a list of tuples or None
@@ -348,23 +368,46 @@ class _abstractState( object ):
         inputNodes = self.root.findall( "./data/input")
         res = []
         
+        def xml_to_tuple( node ):
+            fileName= str( node.text)
+            size = long( node.get( "size" ) )
+            fmt = node.get( "fmt" , None ) 
+            if fmt :
+                fmt = str( fmt )
+            return ( fileName , size , fmt )
+            
         for inputNode in inputNodes:
             parameterNode = inputNode.find( 'parameter' )
             parameterName = parameterNode.find( 'name').text
-            fileNodes = inputNode.findall( "./file" )
+            fileNodes = inputNode.findall( "./file[raw]" )
             if fileNodes:
                 files =[]
-                formattedFileNodes = inputNode.findall( "./formattedFile" )
-                fileNodes += formattedFileNodes
-
                 for fileNode in fileNodes:
-                    fileName= str( fileNode.text )
-                    size = long( fileNode.get( "size" ) )
-                    fmt = fileNode.get( "fmt" , None ) 
-                    if fmt :
-                        fmt = str( fmt )
-                    files.append( ( fileName , size , fmt ) )
+                    rawFile = fileNode.find( 'raw')
+                    files.append( xml_to_tuple( rawFile ) )
+                    convFile = fileNode.find( 'formattedFile' )
+                    if convFile is not None :
+                        files.append( xml_to_tuple( convFile ) )
                 res.append( ( parameterName , files ) )
+            else:
+                # handle Mobyle1.5->Mobyle 1.0.7 compatibility
+                # in the parsing of <file> tags which have changed
+                # with the multiple inputs options. 
+                fileNodes = inputNode.findall( "./file" )
+                if fileNodes:
+                    files =[]
+                    formattedFileNodes = inputNode.findall( "./formattedFile" )
+                    fileNodes += formattedFileNodes
+    
+                    for fileNode in fileNodes:
+                        fileName= str( fileNode.text )
+                        size = long( fileNode.get( "size" ) )
+                        fmt = fileNode.get( "fmt" , None ) 
+                        if fmt :
+                            fmt = str( fmt )
+                        files.append( ( fileName , size , fmt ) )
+                    res.append( ( parameterName , files ) )
+                
         if res:
             return res
         else:
@@ -532,6 +575,18 @@ class _abstractState( object ):
                 raise MobyleError ,err
         return fh
 
+    def getHost( self):
+        """
+        @return: the host of the job
+        @rtype: string
+        """
+        self._parse()
+        host = self.root.find("./host")
+        if host is not None:
+            return host.text
+        else:
+            return None
+
     def setHost( self, host ):
         """
         update the node host or if this node doesn't exist make it
@@ -540,7 +595,7 @@ class _abstractState( object ):
         """
         self._updateNode( self.root , 'host' , host  )
 
-    def setInputDataFile( self , paramName , File , fmtProgram = None  , formattedFile = None ):
+    def addInputDataFile( self , paramName , File , fmtProgram = None  , formattedFile = None ):
         """
         if the node result exist add new nodes for files, otherwise create a new node results and add nodes for files
         @param paramName: the parameter name to update or create
@@ -552,41 +607,41 @@ class _abstractState( object ):
         @param formattedFile: the file after reformatting
         @type formattedFile: a tuple of ( string fileName , long size , string data format )
         """
+        #js_log.debug( "setInputDataFile pas d'input parameter avec le nom %s " %paramName)
+        dataNode = self.root.find( './data' )
+        if dataNode is None:
+            #js_log.debug( "pas de noeud data" )
+            dataNode = etree.Element( 'data' )
+            self.root.append( dataNode )
+       
         try:
-            inputNode = self.root.xpath( './data/input/parameter[ name = "'+ paramName + '" ]')[0]
-            raise MobyleError , "this input data already exist " + paramName  
+            inputNode = self.root.xpath( './data/input[parameter/name = "'+ paramName + '" ]')[0]
         except IndexError :
-            #js_log.debug( "setInputDataFile pas d'input parameter avec le nom %s " %paramName)
-            dataNode = self.root.find( './data' )
-            if dataNode is None:
-                #js_log.debug( "pas de noeud data" )
-                dataNode = etree.Element( 'data' )
-                self.root.append( dataNode )
-            
             inputNode = self._createInOutNode( 'input', paramName )
             #js_log.debug( "1 nouvel inputNode a ete cree" )
             dataNode.append( inputNode )
-            
-            fileName , size , fmt = File
+        fileNode = etree.Element( 'file' )
+        inputNode.append( fileNode )    
+        fileName , size , fmt = File
+        attr = {}
+        attr[ 'size' ] = str( size ) 
+        if fmt :
+            attr[ 'fmt' ] = fmt
+        self._addTextNode( fileNode , 'raw' , os.path.basename( fileName ) , attr )    
+        if fmtProgram :
+            self._addTextNode( fileNode , 'fmtProgram' , fmtProgram )
+        if formattedFile :
+            formattedFileName , formattedSize , formattedFmt = formattedFile
             attr = {}
-            attr[ 'size' ] = str( size ) 
-            if fmt :
-                attr[ 'fmt' ] = fmt
-            self._addTextNode( inputNode , 'file' , os.path.basename( fileName ) , attr )    
-            if fmtProgram :
-                self._addTextNode( inputNode , 'fmtProgram' , fmtProgram )
-            if formattedFile :
-                formattedFileName , formattedSize , formattedFmt = formattedFile
-                attr = {}
-                attr[ 'size' ] =  str( formattedSize )
-                if formattedFmt :
-                    attr[ 'fmt' ] = formattedFmt
-                self._addTextNode( inputNode , 'formattedFile' , os.path.basename( formattedFileName ) , attr  )
+            attr[ 'size' ] =  str( formattedSize )
+            if formattedFmt :
+                attr[ 'fmt' ] = formattedFmt
+            self._addTextNode( fileNode , 'formattedFile' , os.path.basename( formattedFileName ) , attr  )
                 
                 
-    def renameInputDataFile(self , paramName , newName ):
+    def renameInputDataFile(self , paramName , oldName, newName ):
         """
-        Change the name of an infut file
+        Change the name of an input file
         @param paramName: the parameter name 
         @type paramName: string
         @param newName: the new value of the input file name
@@ -597,13 +652,17 @@ class _abstractState( object ):
         except IndexError :
             raise MobyleError, "try to rename an unkown Input File parameter: %s" %paramName
         
-        fileNode = inputNode.find( './file' )
-        try:
-            fileNode = inputNode.xpath( './formattedFile' )[0]
-        except IndexError:
-            pass
-        fileNode.set( 'origName' , fileNode.text )
-        fileNode.text = newName
+        fileNodes = inputNode.findall( 'file' )
+        for fileNode in fileNodes:
+            rawNode = fileNode.find( 'raw' )
+            if rawNode.text == oldName:
+                rawNode.set( 'origName' , rawNode.text )
+                rawNode.text = newName
+            formattedNode = fileNode.find( 'formattedFile' )
+            if formattedNode is not None:
+                if formattedNode.text == oldName:
+                    formattedNode.set( 'origName' , formattedNode.text )
+                    formattedNode.text = newName
         
         
     def setInputDataValue( self , paramName , value  ):
@@ -747,37 +806,6 @@ class _abstractState( object ):
             return None
     
     
-    def getFormattedData( self ):
-            """
-            for input files return a dict like cas des input files uniquement
-                  file: valeur
-                  fileFmt: valeur
-                  program: valeur
-                  formattedFile: valeur
-                  formattedFileFmt: valeur
-            """
-            inputFileNodes = self.root.xpath( './data/input[ file ]' )
-            fdata = {}
-            
-            for inputFileNode in inputFileNodes:
-                name = inputFileNode.find( './parameter/name' ).text
-                FileName = inputFileNode.find( './file').text
-                fileFmt = inputFileNode.xpath( './file/@fmt' )[0]
-                program = inputFileNode.find( './fmtProgram').text
-                try:
-                    formattedFile = inputFileNode.xpath( './formattedFile/text()' )[0]
-                    formattedFileFmt = inputFileNode.xpath( './formattedFile/@fmt')[0]
-                except IndexError:
-                    formattedFile = None
-                    formattedFileFmt = None
-                
-                fdata[ name ] = { 'file'            : FileName,
-                                 'fileFmt'          : fileFmt,
-                                 'fmtprogram'       : program,
-                                 'formattedFile'    : formattedFile,
-                                 'formattedFileFmt' : formattedFileFmt 
-                                 }
-            return fdata
 
 class JobState( object ):
     """
@@ -863,14 +891,17 @@ class JobState( object ):
 
 
     def createState( self , service ):
-        if self.state :
+        if self.state:
             msg = "cannot create a JobState, Jobstate already exists"
             raise MobyleError , msg
         else:
             if isinstance(service, Program):
                 if self._islocal:
                     self.state = ProgramJobState( uri = self._MyUri )
-                    self.state.setDefinition( service.getUrl())
+                    if hasattr(service, 'simulation_path'):
+                        self.state.setSimulationDefinition(service)
+                    else:
+                        self.state.setDefinition( service.getUrl())
                 else:
                     msg ="can't create a State on a distant Mobyle Server"
                     raise MobyleError , msg
@@ -915,6 +946,7 @@ class ProgramJobState( _abstractState ):
     """
     ProgramJobState Object manages the information in index.xml file for a program job
     """
+
     def isWorkflow(self):
         return False
     
@@ -938,6 +970,18 @@ class ProgramJobState( _abstractState ):
             for i in nodes:
                 p.remove(i)  
         self.root.insert(0, program_node )
+
+    def setSimulationDefinition( self , service ):
+        """Copy the program definition in the program job for future reference"""
+        program_def  = etree.parse( service.simulation_path )
+        program_node = program_def.getroot()
+        #if a node 'program already exists , remove it bfore to add the new one
+        nodes = self.root.xpath( 'program' )
+        if nodes:
+            p = nodes[0].getparent()
+            for i in nodes:
+                p.remove(i)  
+        self.root.insert(0, program_node )
         
     
     def getDefinition(self):
@@ -1102,4 +1146,4 @@ class WorkflowJobState( _abstractState ):
                 # this happens if the job index.xml file cannot be retrieved, especially if it is a removed subtask (e.g., remote)
                 pass
             
-        return subjobs
\ No newline at end of file
+        return subjobs
