@@ -120,55 +120,66 @@ def parseProgram( programNode , debug = 0 ):
 
 def parseHeader( service ,  headNode , context = None ):
     """
-    fill the head of the service with thw element from the headNode
+    fill the head of the service with the element from the headNode
     @param service: the service
     @type service: a Program instance or WorkflowDef instance
     @param headNode: a node representing a header
     @type headNode: a dom object 
     """
-    header = Mobyle.Service.Header()
-    name = headNode.find( "name" ).text
-    header.setName( name )
-    try:
-        version = headNode.find( "version" ).text
-        header.setVersion( version )
-    except AttributeError:
-        pass
-    title = headNode.find( "doc/title" ).text
-    header.setTitle( title )
-    doclinks = headNode.findall( "doc/doclink" )
-    for doclink in doclinks:
-        header.addDoclink( doclink.text )
-    categoryNodes = headNode.findall( "category" )
-    categories = []
-    for categoryNode in categoryNodes:
-        categories.append( categoryNode.text )
-    if categories:
-        header.addCategories( categories )
-    try:
-        commandNode = headNode.find( "command" )
-        command = commandNode.text
-        type = commandNode.get( "type" )
-        path = commandNode.get( "path" )
-        if type and path:
-            header.setCommand( command , type = type , path = path )
-        elif type:
-            header.setCommand( command , type = type )
-        elif path:
-            header.setCommand( command , path = path )
-        else:
-            header.setCommand( command )
-    except AttributeError:
-        pass
-    envNodes = headNode.findall( "env" )
-    for envNode in envNodes:
+    
+
+    def parse( package_or_program , pack_or_prg_node):
+        name = pack_or_prg_node.find( "./name" ).text
+        package_or_program.setName( name )
         try:
-            envName = envNode.get( 'name')
-            envValue = envNode.text
-            header.addEnv( envName , envValue )
-        except IndexError:
-            raise ParserError , "invalid env element in head"
-    return header  
+            version = pack_or_prg_node.find( "./version" ).text
+            package_or_program.setVersion( version )
+        except AttributeError:
+            pass
+        title = pack_or_prg_node.find( "./doc/title" ).text
+        package_or_program.setTitle( title )
+        doclinks = pack_or_prg_node.findall( "./doc/doclink" )
+        for doclink in doclinks:
+            package_or_program.addDoclink( doclink.text )
+        categoryNodes = pack_or_prg_node.findall( "./category" )
+        categories = []
+        for categoryNode in categoryNodes:
+            categories.append( categoryNode.text )
+        if categories:
+            package_or_program.addCategories( categories )
+        try:
+            commandNode = pack_or_prg_node.find( "command" )
+            command = commandNode.text
+            type = commandNode.get( "type" )
+            path = commandNode.get( "path" )
+            if type and path:
+                package_or_program.setCommand( command , type = type , path = path )
+            elif type:
+                package_or_program.setCommand( command , type = type )
+            elif path:
+                package_or_program.setCommand( command , path = path )
+            else:
+                package_or_program.setCommand( command )
+        except AttributeError:
+            pass
+        envNodes = pack_or_prg_node.findall( "env" )
+        for envNode in envNodes:
+            try:
+                envName = envNode.get( 'name')
+                envValue = envNode.text
+                package_or_program.addEnv( envName , envValue )
+            except IndexError:
+                raise ParserError , "invalid env element in head"
+        
+    pack_node = headNode.find('package')
+    package = None
+    if pack_node is not None:
+        package = Mobyle.Service.Package()
+        parse( package, pack_node )
+    prog_head_node = headNode
+    program_header =  Mobyle.Service.ProgramHeader()
+    parse( program_header , prog_head_node)
+    return Mobyle.Service.Header(package , program_header)          
 
 
 def parseParagraph( paragraphNode , evaluator  = None , dataTypeFactory = None , context = None):
