@@ -125,12 +125,14 @@ class Registry(DefNode):
         self.programs = []
         self.workflows = []
         self.viewers = []
+        self.tutorials = []
         self.servers = []
         self.serversByName = {}
         self.serversByUrl = {}
         self.programsByUrl = {}
         self.workflowsByUrl={}
         self.viewersByUrl = {}
+        self.tutorialsByUrl= {}
         self.servers_path=_cfg.servers_path()
     
     def load( self):
@@ -200,23 +202,27 @@ class Registry(DefNode):
                         self.addViewer(viewer)
                     except IndexError, e:
                         r_log.error("Error while loading %s: %s" % (name, e))
+                        
+                for name in properties[ 'tutorials' ]:
+                    try:                        
+                        url = self.getTutorialUrl(name)
+                        path = self._computeTutorialPath(name)
+                        tt = TutorialDef( name = name,
+                                              url = url,
+                                              path = path,
+                                              server = server
+                                            )
+                        # service disabled
+                        if _cfg.isDisabled( portalID = "%s.%s" %( server.name, name ) ): 
+                            tt.disabled = True
+                        # service with restricted access
+                        if not( _cfg.isAuthorized( url )):
+                            tt.authorized = False
+                        self.addTutorial( tt )
+                    except IndexError, e:
+                        r_log.error("Error while loading %s: %s" % (name, e))
+                        
 
-    def loadSessionServices( self, session):
-        """ 
-        This method allows to add BMW-defined workflows to the registry, so that
-        they can be run in Mobyle
-        """
-        session_workflow_path_list = glob( os.path.join(session.getDir() , 'BMW','*.graphml' ) )
-        session_workflow_list = [ (os.path.basename( p )[:-8],p) for p in session_workflow_path_list ]
-        for sw in session_workflow_list:
-            
-            wf = WorkflowDef( name = sw[0],
-                                  url = session.url+'/BMW/'+sw[0]+'_mobyle.xml',
-                                  path = sw[1],
-                                  server = self.serversByName['local']
-                                )
-            self.addWorkflow(wf)
-    
     def addServer(self, server):
         self.servers.append( server )
         self.serversByName[ server.name ] = server
@@ -240,6 +246,12 @@ class Registry(DefNode):
         self.serversByName[ viewer.server.name ].viewers.append( viewer )
         self.serversByName[ viewer.server.name ].viewersByName[ viewer.name ] = viewer
     
+    def addTutorial(self, tutorial ):
+        self.tutorials.append( tutorial )
+        self.tutorialsByUrl[ tutorial.url ] = tutorial
+        self.serversByName[ tutorial.server.name ].tutorials.append( tutorial )
+        self.serversByName[ tutorial.server.name ].tutorialsByName[ tutorial.name ] = tutorial
+    
     def has_service(self , service ):
         """
         @param service: the service to test the existance.
@@ -265,7 +277,12 @@ class Registry(DefNode):
                 return True
             except KeyError :
                 return False
-
+        elif isinstance( service , TutorialDef ):
+            try:
+                self.serversByName[ service.server.name ].tutorialsByName[ service.name ]
+                return True
+            except KeyError :
+                return False
 
     def pruneService(self, service):
         """
@@ -304,6 +321,17 @@ class Registry(DefNode):
 #                    del self.serversByName[service.server.name]
 #                    self.servers.remove(service.server)
 
+        elif isinstance( service , TutorialDef ):
+            if self.has_service(service):
+                self.tutorials.remove(service)
+                del self.tutorialsByUrl[service.url]
+                self.serversByName[service.server.name].tutorials.remove(service)
+                del self.serversByName[service.server.name].\
+                    tutorialsByName[service.name]
+#                if (len(service.server.services)==0):
+#                    del self.serversByName[service.server.name]
+#                    self.servers.remove(service.server)
+
 
     def _getServerProperties(self):
         """
@@ -314,7 +342,8 @@ class Registry(DefNode):
                                  'jobBase': string ,
                                  'programs': []  ,
                                  'workflows' : [] ,
-                                 'viewers': [] #available only for local server , }
+                                 'viewers': [] #available only for local server ,
+                                 'tutorials': [] #available only for local server }
         """
         imported_portals = _cfg.portals()
         properties = {}
@@ -335,6 +364,8 @@ class Registry(DefNode):
                     properties[ server_name ][ 'repository' ] = _cfg.repository_url()
                     deployed_viewers_path = glob(os.path.join( server_dir_path , ViewerDef.directory_basename ,"*.xml") )
                     properties[ server_name ][ 'viewers' ]    = [ os.path.basename( p )[:-4] for p in deployed_viewers_path ] 
+                    deployed_tutorials_path = glob(os.path.join( server_dir_path , TutorialDef.directory_basename ,"*.xml") )
+                    properties[ server_name ][ 'tutorials' ]    = [ os.path.basename( p )[:-4] for p in deployed_tutorials_path ]
                     properties[ server_name ][ 'jobsBase' ]   = _cfg.results_url()
                 elif server_name in imported_portals:
                     properties[ server_name ][ 'url' ]        = imported_portals[ server_name ][ 'url' ]
@@ -362,7 +393,11 @@ class Registry(DefNode):
         return "%s/services/servers/local/%s/%s.xml" %( self.serversByName[ 'local' ].repository,
                                  ViewerDef.directory_basename , 
                                  name )
-            
+        
+    def getTutorialUrl(self, name ):
+        return "%s/services/servers/local/%s/%s.xml" %( self.serversByName[ 'local' ].repository,
+                                 TutorialDef.directory_basename , 
+                                 name )        
     def getJobPID(self, url):
         """
         @param url: the url of 
@@ -399,6 +434,8 @@ class Registry(DefNode):
     def getViewerPath(self, name):
         return os.path.join( self.servers_path , 'local', ViewerDef.directory_basename  , name + '.xml')
     
+    def getTutorialPath(self, name):
+        return os.path.join( self.servers_path , 'local', TutorialDef.directory_basename  , name + '.xml')
     
     def getProgramPath(self, name, server_name ='local'):
         if server_name in self.serversByName:
@@ -414,6 +451,9 @@ class Registry(DefNode):
       
     def _computeWorkflowPath( self , name , server_name= 'local' ):  
         return os.path.join( self.servers_path , server_name, WorkflowDef.directory_basename , name + '.xml') 
+
+    def _computeTutorialPath( self , name , server_name= 'local' ):  
+        return os.path.join( self.servers_path , server_name, TutorialDef.directory_basename , name + '.xml') 
       
     def getServerByJobId(self,jobId):
         for server in self.servers:
@@ -483,7 +523,13 @@ class ViewerDef(ServiceDef):
     type = "viewer"
     directory_basename = "viewers"        
    
-
+class TutorialDef(ServiceDef):
+    """
+    TutorialDef is the class that provides the tutorial information to the registry
+    """
+    type = "tutorial"
+    directory_basename = "tutorials"        
+   
 
 
 class ServerDef(DefNode):
@@ -523,6 +569,8 @@ class ServerDef(DefNode):
         self.workflowsByName = {}
         self.viewers = []
         self.viewersByName = {}
+        self.tutorials = []
+        self.tutorialsByName = {}
         self.path = os.path.join( _cfg.services_path() , self.name )
 
     def __cmp__(self, other):
@@ -538,7 +586,6 @@ class ServerDef(DefNode):
             return -1
         else:
             return cmp(self.name.lower(), other.name.lower())
-        r_log.error(self.name)
 
 class CategoryDef(DefNode):
     """
@@ -562,7 +609,22 @@ class CategoryDef(DefNode):
         self.categories = [] # top-level categories
 
 class ServiceTypeDef(CategoryDef):
-    pass
+    def __cmp__(self, other):
+        """
+        Comparison operator that allows to classify the service types
+        with tutorials at the end
+        @param other: the other node to which self is compared
+        @type other: DefNode
+        @return: the comparison result
+        @rtype: boolean
+        """
+        if other.name=='Tutorials':
+            return -1
+        elif self.name=='Tutorials':
+            return 1
+        else:
+            return cmp(self.name.lower(), other.name.lower())
+
         
 registry = Registry()
 registry.load()
