@@ -146,7 +146,7 @@ class Session( object ):
             raise UserValueError( msg = resp.user_message )
             
         transaction = self._getTransaction( Transaction.WRITE )
-        transaction.setEmail( email )
+        transaction.setEmail( str(email) )
         transaction.commit()
 
     ##############################
@@ -935,8 +935,8 @@ class Session( object ):
         for j in jobs:
             flattened_jobs.append(j)
             flattened_jobs.extend(j['subjobs'])
-        j = [j for j in flattened_jobs if j['jobID']==jobID].pop()
-        return j
+        j_list = [j for j in flattened_jobs if j['jobID']==jobID]
+        return j_list.pop() if len(j)>0 else None
     
     
     def getJob(self , jobID ):
