@@ -14,10 +14,10 @@ from time import sleep , time
 
 from Mobyle.Status import Status
 from Mobyle.MobyleError import MobyleError
-from Mobyle.Utils import parse_xml_file
+#from Mobyle.Utils import parse_xml_file
 
 import logging
-_log = logging.getLogger( 'Mobyle.StatusManager' )
+_log = logging.getLogger( __name__ )
 
 import sys
 import os.path
@@ -104,7 +104,8 @@ class StatusManager(object):
         #If I do not got a lock a IOError is raised
         try:
             parser = etree.XMLParser( no_network = False )
-            doc = parse_xml_file(File , parser)
+            #doc = parse_xml_file(File , parser)
+            doc = etree.parse(File , parser)
             root = doc.getroot()
         except Exception , err:
             msg = "error in parsing status %s : %s" % ( File.name , err )
@@ -137,9 +138,9 @@ class StatusManager(object):
             message_node = root.find( "message" )
             message_node.text = status.message
         except Exception, err:
-            msg = "error in parsing status %s : %s (status= %s; msg= %s)" % ( File.name , err , status , status.message)
+            msg = "error in parsing status %s : %s" % ( File.name , err )
             _log.error( msg )
-            _log.debug("%f : %s : setStatus UNLOCK " %( time() , File.name ) )
+            _log.debug("%f : %s : setStatus UNLOCK " %( time() , fileName ) )
             fcntl.lockf( File , fcntl.LOCK_UN  )
             File.close()
             raise MobyleError( msg )
@@ -188,7 +189,8 @@ class StatusManager(object):
             return Status( code= -1 )
         try:
             parser = etree.XMLParser( no_network = False )
-            doc = parse_xml_file( File , parser )
+            #doc = parse_xml_file( File , parser )
+            doc = etree.parse(File, parser)
             root = doc.getroot()
         except Exception , err:
             pass
@@ -212,7 +214,8 @@ class StatusManager(object):
     def _fall_back_setStatus(self , job_path  , status ):
         parser = etree.XMLParser( no_network = False )
         index_path = os.path.join( job_path ,'index.xml')
-        doc = parse_xml_file( index_path , parser)
+        #doc = parse_xml_file( index_path , parser)
+        doc = etree.parse(index_path, parser)
         root = doc.getroot()
         status_node = root.find( "./status" )
         try:
@@ -278,7 +281,8 @@ class StatusManager(object):
 
     def _fall_back_getStatus(self , job_path ):
         parser = etree.XMLParser( no_network = False )
-        doc = parse_xml_file( os.path.join( job_path ,'index.xml') , parser)
+        #doc = parse_xml_file( os.path.join( job_path ,'index.xml') , parser)
+        doc = etree.parse(os.path.join(job_path, 'index.xml'), parser)
         root = doc.getroot()
         try:
             status = root.find( "./status/value" ).text
