@@ -9,14 +9,14 @@
 
 #import os 
 #from time import localtime, strftime , strptime
+from time import strftime
 
 from logging import getLogger
 u_log = getLogger( __name__ )
 
 from Mobyle.MobyleError import MobyleError , UserValueError
 from Mobyle.Admin import Admin
-
-
+#from Mobyle.Status import Status
 
 def executionLoader( jobID = None , alias = None , execution_config=None):
     assert ( bool( jobID ) +  bool( alias ) + bool( execution_config )== 1), "please provide either a jobID, an alias or an execution_config"
@@ -202,7 +202,7 @@ def killJob( jobID ):
         if js.isWorkflow():
             job = WorkflowJob( id= jobID )
         else:
-            job= Job(ID = jobID)
+            job= Job( ID= jobID )
         try:
             job.kill()
         except MobyleError , err :
@@ -212,9 +212,10 @@ def killJob( jobID ):
         msg = ''
         for jobID , msgErr in errors :
             msg = "%s killJob( %s ) - %s\n" % ( msg , jobID , msgErr )
+            
         raise MobyleError , msg
 
-def safeFileName(fileName):
+def safeFileName( fileName ):
     import string , re
     
     if fileName in ( 'index.xml' , '.admin' , '.command' ,'.forChild.dump' ,'.session.xml'):
@@ -222,16 +223,13 @@ def safeFileName(fileName):
     
     for car in fileName :
         if car not in string.printable : #we don't allow  non ascii char
-            try:
-                fileName = fileName.replace( car , '_')
-            except Exception, err:
-                u_log.error( "error in safeFileName: %s \ncall with fileName= %s"%fileName, exc_info= True)
-                raise MobyleError( "Internal Mobyle Server Error")
+            fileName = fileName.replace( car , '_')
+    
     #SECURITY: substitution of shell special characters
     fileName = re.sub( "[ ~%#\"\'<>&\*;$`\|()\[\]\{\}\?\s ]" , '_' , fileName )
                   
     #SECURITY: transform an absolute path in relative path
-    fileName = re.sub( "^.*[\\\:/]", "" , fileName )
+    fileName = re.sub( "^.*[\\\]", "" , fileName )
     
     return fileName
 
@@ -269,7 +267,7 @@ def zipFiles( zip_filename , files ):
     from time import localtime
     from Mobyle.StatusManager import StatusManager
     
-    myZipFile = zipfile.ZipFile( zip_filename  , "w" )
+    myZipFile = zipfile.ZipFile( zip_filename, "w", allowZip64 = True )
     for filename , arc_filename in files:
         if arc_filename == 'index.xml':
             from lxml import etree
@@ -288,22 +286,77 @@ def zipFiles( zip_filename , files ):
         try:
             size = os.path.getsize( filename )
         except OSError , err:
-            u_log.critical( "error durring zipping files: %s"%(err) , exc_info = True)
+            u_log.critical( "error during zipping files: %s"%(err) , exc_info = True)
             continue
-        if size > 0 and size < 10 :
+        if size > 0 and size < 10:
             myZipFile.write( filename   , arc_filename , zipfile.ZIP_STORED )
-        elif size >= 10 and size < 2147483648 : #2Go 
-            myZipFile.write(   filename   , arc_filename , zipfile.ZIP_DEFLATED )
-        elif size >= 2147483648 :#2Go
-            myZipInfo = zipfile.ZipInfo( arc_filename , localtime()[:6] )
-            myZipInfo.external_attr = 2175008768   # set perms to 644
-            myZipFile.writestr(  myZipInfo  , "Sorry this file result is too large ( > 2GiB ) to be included in this archive." )    
+        elif size >= 10:  
+            myZipFile.write(filename, arc_filename, zipfile.ZIP_DEFLATED)
         else:
             #the file is empty we don't add it to this archive
             pass   
     myZipFile.close()
     return  zip_filename
 
+def emailHelpRequest( cfg, userEmail, registry, job_id, message, session, error_parameter, error_message ):
+    from Mobyle.Net import Email, EmailAddress 
+    if(message is None):
+        raise UserValueError(msg='please provide a request message.')
+    userAddress = EmailAddress(userEmail)            
+    if job_id:
+        jobServer = registry.getServerByJobId(job_id)
+    else:
+        jobServer = registry.serversByName['local']
+    if cfg.mailHelp()!=jobServer.help:
+        # generate a list of unique email addresses from the execution server and portal server help addresses
+        help_addresses = cfg.mailHelp() + list(set(cfg.mailHelp())-set(jobServer.help))
+        helpAddress = EmailAddress(help_addresses)
+    else:
+        helpAddress = EmailAddress(cfg.mailHelp())
+    helpEmail = Email(helpAddress)
+    job_status = "[not provided]"
+    job_date = "[not provided]"
+    execution_alias = "[not provided]"
+    number = "[not provided]"
+    queue = "[not provided]"
+    if job_id is not None:
+        job_info = session.getJob(job_id)
+        job_status = job_info['status']
+        job_date = strftime("%a, %d %b %Y %H:%M:%S +0000", job_info['date'])
+        try:
+            from Mobyle.JobState import url2path
+            job_path = url2path(job_id)
+            adm = Admin(job_path)
+            execution_alias = adm.getExecutionAlias()
+            number = adm.getNumber()
+            queue = adm.getQueue()
+        except MobyleError:
+            pass
+    else:
+        job_id = "[not provided]"
+    msgDict = {
+                 'USER': userAddress,
+                 'SENDER': cfg.sender(),
+                 'MSG': message,
+                 'SESSION_ID': session.getKey(),
+                 'SESSION_EMAIL': session.getEmail(),
+                 'SESSION_ACTIVATED': session.isActivated(),
+                 'SESSION_AUTHENTICATED': session.isAuthenticated(),
+                 'JOB_URL': job_id,
+                 'JOB_DATE': job_date,
+                 'JOB_STATUS': job_status,
+                 'JOB_ERROR_PARAM': error_parameter,   
+                 'JOB_ERROR_MSG': error_message,
+                 'HELP': str(helpAddress),
+                 'EXECUTION_ALIAS': execution_alias,
+                 'NUMBER': number,
+                 'QUEUE': queue
+              } 
+    helpEmail.send('HELP_REQUEST' , msgDict)
+    receiptEmail = Email( userAddress )
+    receiptEmail.send('HELP_REQUEST_RECEIPT' , msgDict)
+    return helpEmail.getBody()
+
 def emailResults( cfg , userEmail, registry, ID, job_path, serviceName, jobKey, FileName = None ):
     """
     @param cfg: the configuration of Mobyle    
@@ -408,25 +461,3 @@ def indent(elem, level=0):
     else:
         if level and (not elem.tail or not elem.tail.strip()):
             elem.tail = i
-
-def parse_xml_file(file_handle, parser):
-    """
-    wrapper for the lxml etree.parse() function
-    the behavior of lxml.parse changes between v2.2 and v2.3:
-    in v2.3 it closes automatically the file after parsing it,
-    breaking the file-locking mechanism.
-    this function uses a workaround for versions 2.3.x
-    @param file_handle: the file handle for the XML file to be parsed
-    @type zip_filename: {file}
-    @param parser: parser object to pass to etree.parse
-    @type parser: {lxml.etree._BaseParser}
-    @return: the parsed document as an ElementTree object
-    @rtype: {lxml.etree._ElementTree}
-    """
-    from lxml import etree
-    if etree.__version__.startswith('2.3'):
-        from StringIO import StringIO
-        return etree.parse( StringIO(''.join(file_handle.readlines())) , parser )
-    else:
-        return etree.parse(file_handle)
-    
\ No newline at end of file
