@@ -106,7 +106,11 @@ class WorkflowJob(object):
                 # setting parameters which have a default value (important for hidden parameters which are not 
                 # accessed by JobFacade...
                 if not(parameter.isout) and len(parameter.vdef)!=0:
-                    self.set_value(parameter.name, value=parameter.getVdef())
+                    vdef = parameter.getVdef()
+                    if type(vdef)==dict:
+                        self.set_value(parameter.name,src=vdef['src'],srcFileName=vdef['srcFileName'])
+                    else:
+                        self.set_value(parameter.name, value=vdef)
             
     def getDir(self):        
         """ returns the absolute path of the workflow job directory """
@@ -143,7 +147,7 @@ class WorkflowJob(object):
         elif src is not None:
             log.debug("copying %s parameter value from %s/%s" %(parameter_name, src,srcFileName))
         else:
-            log.error("no VALUE or SOURCE URL specified for %s parameter." % parameter_name)            
+            log.error("no VALUE or SOURCE URL specified for %s parameter." % parameter_name)
         """ set a parameter value """
         self.parameters[parameter_name] = value
         self.parameters[parameter_name + '.src'] = src
@@ -169,7 +173,7 @@ class WorkflowJob(object):
                 src = DataProvider.get(src)
             file_name, size = mt.toFile( value , self , file_name, src , srcFileName  )
             if not(wf_parameter.isout):
-                self.jobState.setInputDataFile(parameter_name, (file_name, size, None))
+                self.jobState.addInputDataFile(parameter_name, (file_name, size, None))
             else:
                 self.jobState.setOutputDataFile(parameter_name, [(file_name, size, None)])
         else:
@@ -429,11 +433,16 @@ class WorkflowJob(object):
             for o in [l for l in self.workflow.links if l.from_task==t.id]:
                 self.data.append({'type':'task_output','task':t, 'parameter_id':o.from_parameter})
             for iv in t.input_values:
+                if iv.name in [l.to_parameter for l in self.workflow.links if l.from_task==t.id]:
+                    log.debug("ignoring input value for task %s parameter %s which has been provided by a link." %\
+                              (t.id, iv.name))
+                    continue
                 ti = {'type':'task_input','task':t, 'parameter_id':iv.name}
+                if iv.reference is not None:
+                    ti['src'] = iv.reference
+                    ti['srcFileName'] = iv.safe_name
                 if iv.value is not None:
                     ti['value'] = iv.value
-                elif iv.reference:
-                    ti['src'] = iv.reference
                 self.data.append(ti)
         for l in self.workflow.links:
             log.debug('preparing link %s' % l)
@@ -451,7 +460,7 @@ class WorkflowJob(object):
         mandatory_list = [p for p in self.workflow.parameters if not(p.isout) and p.ismandatory and (p.vdef is None or p.vdef=='')]
         for p in mandatory_list:
             if not(self.parameters.get(p.name)) and not(self.parameters.get('%s.src' % p.name)):
-                raise UserValueError(parameter = p, msg = "This parameter is mandatory" )            
+                raise UserValueError(parameter = p, msg = "This parameter is mandatory" )
 
     def _iterate_tasks(self):
         """launch and monitor task executions"""
@@ -498,16 +507,16 @@ class WorkflowJob(object):
                         if not(resp.has_key('id')):
                             raise WorkflowJobError(resp.get('errormsg',''))
                     except Exception, e:
-                        log.error("error during submission of task %s(%s): %s" \
-                                                  %(t.id, t.description, e.message),exc_info=True)
-                        raise WorkflowJobError("error during submission of task %s(%s): %s" \
-                                                  %(t.id, t.description, e.message))
+                        log.error("error during submission of task %s%s: %s" \
+                                                  %(t.id, "(%s)" % t.description if t.description else "", e.message),exc_info=True)
+                        raise WorkflowJobError("error during submission of task %s%s: %s" \
+                                                  %(t.id, "(%s)" % t.description if t.description else "", e.message))
                     job_entry['job_id'] = resp['id']
-                    if resp.has_key('errorparam') or resp.has_key('errormsg'):
-                        raise WorkflowJobError("error during submission of task %s(%s).\n job %s message: %s: %s." \
-                                                  %(t.id, t.description,job_entry['job_id'],resp.get('errorparam'),resp.get('errormsg')))
                     self.jobState.setTaskJob(t,job_entry['job_id'])
                     self.jobState.commit()
+                    if resp.has_key('errorparam') or resp.has_key('errormsg'):
+                        raise WorkflowJobError("error during submission of task %s%s.\n job %s message: %s: %s." \
+                                                  %(t.id, "(%s)" % t.description if t.description else "",job_entry['job_id'],resp.get('errorparam'),resp.get('errormsg')))
                     su_signal = self._process_subjob_status_update(j, job_entry, t)
                     job_signal = job_signal or su_signal
                     log.debug('job for task %s: %s' % (t.id, job_entry['job_id']))
