@@ -165,10 +165,11 @@ def process(self):
         jobDetails = None
         if self.session is not None:
             job = self.session.getJobBMPS(jobUrl)
-            jf = JobFacade.getFromJobId( job[ 'jobID' ] )
-            job['subjobs']  = jf.getSubJobs() 
-            job['jobPID'] = jobId
-            jobDetails = get_formatted_job_entries(job,self.session)
+            if job is not None:
+                jf = JobFacade.getFromJobId( job[ 'jobID' ] )
+                job['subjobs']  = jf.getSubJobs() 
+                job['jobPID'] = jobId
+                jobDetails = get_formatted_job_entries(job,self.session)
         self.jsonMap = [jobDetails]
     elif action_name == 'delete_jobs':
         pids = self.request.getlist('id')
