@@ -10,14 +10,14 @@
 #############################################################
 import mb_cgi
 from Mobyle.JobFacade import JobFacade
-from Mobyle.Registry import registry
+from Mobyle.MobyleError import MobyleError
 
 def process(self):
-    j = JobFacade.getFromService(programUrl=self.request.getfirst('programName',None),workflowUrl=self.request.getfirst('workflowUrl',None))
-    if self.request.getfirst('programName',None) and not ( registry.programsByUrl[ self.request.getfirst( 'programName' , None)].isExported() )\
-        or self.request.getfirst('workflowUrl',None) and not ( registry.workflowsByUrl[ self.request.getfirst( 'workflowUrl' , None)].isExported() ): 
-        return {'errormsg':"Unauthorized access to service %s, which \
-                is restricted to local use." % self.serviceUrl}
+    try:
+        j = JobFacade.getFromService(programUrl=self.request.getfirst('programName',None),workflowUrl=self.request.getfirst('workflowUrl',None))
+    except MobyleError, err:
+        self.jsonMap = {'errormsg': err.message}
+        return
     self.jsonMap = j.create(self.request)
     
 if __name__ == "__main__":
