@@ -22,15 +22,15 @@ def process(self):
         j = JobFacade.getFromService(programUrl=self.request.getfirst('programName',None),workflowUrl=self.request.getfirst('workflowUrl',None))
         self.jsonMap = j.create(self.request, None, self.session)
         if self.jsonMap.has_key('id') and not(self.jsonMap.has_key('errormsg')):
-            j.addJobToSession(self.session, self.jsonMap)
+            self.jsonMap = j.addJobToSession(self.session, self.jsonMap)
             job = self.session.getJob(self.jsonMap['id'])
             jobdatestring = time.strftime( "%x    %X", job['date'])
             self.jsonMap['title'] = job['programName'] + ' - ' + jobdatestring
     except MobyleError, err:
         self.jsonMap = {'errormsg': err.message}
         if hasattr(err, 'param'):
-            self.jsonMap['errorparam']=err.param['parameter'].getName()            
+            self.jsonMap['errorparam']=err.param.getName()            
         return
  
 if __name__ == "__main__":
-    mb_cgi.JSONCGI(processFunction=process,useSession=True)
\ No newline at end of file
+    mb_cgi.JSONCGI(processFunction=process,useSession=True)
